function Ag=adjoint_conv(S,X)
%Ag=adjoint_conv(S,X,K)
%calculates the Riesz representant of A-><X,A\star S>
%
%Input
%       S N*T array
%       X M*T+K-1 array
%Output
%       Ag M*N*K array such that for every M*N*K array A we have
%                   <Ag,A>=<X,A\star S>
%
%       In a way, Ag=X\star adjoint_of_S



[N,T]=size(S);
[M,TpKm1]=size(X);
K=TpKm1+1-T;
Ag=zeros(M,N,K);

for n=1:N

stchetch=S(n,end:-1:1);
    for m=1:M
        xm=X(m,:);     
        amn=fftfilt(stchetch,[xm zeros(1,T-1)]);
        amn=amn(T:TpKm1);
        Ag(m,n,:)=reshape(amn,1,1,[]);

    end
end



end


% Written by Alexis Benichoux, 2011